import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import com.sybase.sup.admin.client.SUPApplication;
import com.sybase.sup.admin.client.SUPObjectFactory;
import com.sybase.sup.admin.context.AgentContext;
import com.sybase.sup.admin.context.ClusterContext;
import com.sybase.sup.admin.context.ServerContext;
import com.sybase.sup.admin.enumeration.application.APPCONNECTION;
import com.sybase.sup.admin.enumeration.application.APPCONNECTION_REGISTRATION;
import com.sybase.sup.admin.enumeration.application.APPCONNECTION_SETTING_FIELD;
import com.sybase.sup.admin.exception.SUPAdminException;
import com.sybase.sup.admin.filter.FilterExpression;
import com.sybase.sup.admin.vo.PaginationResult;
import com.sybase.sup.admin.vo.application.AppConnectionRegistrationRequestVO;
import com.sybase.sup.admin.vo.application.AppConnectionSettingVO;
import com.sybase.sup.admin.vo.application.ApplicationConnectionVO;
import com.sybase.sup.admin.vo.application.filter.AppConnectionFilterSortVO;

public class RegisterApplicationConnections {

	private String supHost = "localhost";
	private int supPort = 2001;
	private String supAgentHost = "localhost";
	private int supAgentPort = 9999;
	private String supAdministrator = "supAdmin";
	private String supAdministratorPassword = "s3pAdmin";
	private String user1 = "user1";
	private String user2 = "user2";
	private String code1 = "1234";
	private String code2 = "2345";
	private String secconf = "admin";
	private String farmId = "0";
	private String expiration = "4";

	private SUPApplication supapp;

	public ClusterContext getClusterContext() {
		ServerContext serverContext = getServerContext();
		return serverContext.getClusterContext("supCluster");
	}

	public ServerContext getServerContext() {
		// Specify connection parameter for connection to SCC Agent.
		AgentContext agentContext = new AgentContext(supAgentHost,
				supAgentPort, supAdministrator, supAdministratorPassword);
		// Specify which server to connect to from the SCC Agent.
		// Note: actual connection is established when the actual request is
		// sent (in this case the supapp.registerApplicationConnections().
		ServerContext serverContext = new ServerContext(supHost, supPort,
				supAdministrator, supAdministratorPassword, true, agentContext);
		return serverContext;
	}

	public RegisterApplicationConnections() throws SUPAdminException {
		// Retrieve the administration interface.
		supapp = SUPObjectFactory.getSUPApplication(getClusterContext());
	}

	public void execute() throws SUPAdminException {
		// Create registration requests
		List<AppConnectionRegistrationRequestVO> requests = createRegistrationRequestVO();

		// Register the applications
		supapp.registerApplicationConnections(getTemplateName(), requests,
				getSettings());

		// Create application connection search criteria using the numeric ids
		AppConnectionFilterSortVO criteria = new AppConnectionFilterSortVO();
		FilterExpression<APPCONNECTION> fe = new FilterExpression<APPCONNECTION>();
		fe = fe.eq(APPCONNECTION.SECURITY_CONF, secconf);
		criteria.setFilterExpression(fe);

		// Do the search
		PaginationResult<ApplicationConnectionVO> result = supapp
				.getApplicationConnections(criteria, 0L, Integer.MAX_VALUE);

		// Print out the application numeric id and its associated user.
		for (ApplicationConnectionVO appConnVO : result.getItems()) {
			System.out.println("Application connection "
					+ appConnVO.getNumericId() + " registered for "
					+ appConnVO.getApplicationUser());
		}

	}

	public String getTemplateName() {
		// Use the default template.
		return "Default";
	}

	public List<AppConnectionRegistrationRequestVO> createRegistrationRequestVO() {
		AppConnectionRegistrationRequestVO acrrvo1 = new AppConnectionRegistrationRequestVO();
		Map<APPCONNECTION_REGISTRATION, Object> req1 = new HashMap<APPCONNECTION_REGISTRATION, Object>();
		req1.put(APPCONNECTION_REGISTRATION.USER_ID, user1);
		req1.put(APPCONNECTION_REGISTRATION.ACTIVATION_CODE, code1);
		req1.put(APPCONNECTION_REGISTRATION.EXPIRATION_HOUR, expiration);
		acrrvo1.setRequest(req1);

		AppConnectionRegistrationRequestVO acrrvo2 = new AppConnectionRegistrationRequestVO();
		Map<APPCONNECTION_REGISTRATION, Object> req2 = new HashMap<APPCONNECTION_REGISTRATION, Object>();
		req2.put(APPCONNECTION_REGISTRATION.USER_ID, user2);
		req2.put(APPCONNECTION_REGISTRATION.ACTIVATION_CODE, code2);
		req2.put(APPCONNECTION_REGISTRATION.EXPIRATION_HOUR, expiration);
		acrrvo2.setRequest(req2);

		List<AppConnectionRegistrationRequestVO> acrrvos = new ArrayList<AppConnectionRegistrationRequestVO>();
		acrrvos.add(acrrvo1);
		acrrvos.add(acrrvo2);

		return acrrvos;
	}

	public AppConnectionSettingVO getSettings() {
		AppConnectionSettingVO settings = new AppConnectionSettingVO();
		Map<APPCONNECTION_SETTING_FIELD, Object> setting = new HashMap<APPCONNECTION_SETTING_FIELD, Object>();
		setting.put(APPCONNECTION_SETTING_FIELD.SECURITY_CONF, secconf);
		setting.put(APPCONNECTION_SETTING_FIELD.SERVER_NAME, supHost);
		setting.put(APPCONNECTION_SETTING_FIELD.SERVER_PORT, "5001");
		setting.put(APPCONNECTION_SETTING_FIELD.ACTIVATION_CODE_EXPIRATION, expiration);
		setting.put(APPCONNECTION_SETTING_FIELD.FARM_ID, farmId);
		settings.setSetting(setting);
		return settings;

	}

	public static void main(String[] args) {
		RegisterApplicationConnections reg;
		try {
			reg = new RegisterApplicationConnections();
			reg.execute();
		} catch (SUPAdminException e) {
			e.printStackTrace();
		}
	}
}
